"""
Naval Fate.

Usage:
  kista.py deploy   <contract_name>            [<args>...]
  kista.py call     <contract_name> <function> [<args>...]
  kista.py transact <contract_name> <function> [<args>...]
  kista.py -h | --help
  kista.py --version

Options:
  -h --help     Show this screen.
  --version     Show version.
"""
import sys, kista, docopt

def f(x):
    try:    return int(x)
    except: pass
    try:    return float(x)
    except: pass
    return x

def hello():
    print("HELLO", sys.argv)

    arguments = docopt.docopt(__doc__, version=kista.version)

    w3 = kista.w3_connect(0)

    if not w3.isConnected():
        print("no connection")
        raise exit(1)

    if arguments['deploy']:

        name = arguments['<contract_name>']
        args = [f(x) for x in arguments['<args>']]

        x = kista.deploy_contractAddress(name, *args)
        print(x)
    
    elif arguments['call']:

        name = arguments['<contract_name>']
        func = arguments['<function>']
        args = [f(x) for x in arguments['<args>']]

        x = w3.eth.contract(address=kista.load_contractAddress(name),
                            abi=kista.load_abi(name))
        x = kista.WrapContract(x)
    
        if func not in x.ras:
            print("func not found")
            raise exit(2)

        result = x.getattr(func)(*args)

        print(result)

    elif arguments['transact']:

        name = arguments['<contract_name>']
        func = arguments['<function>']
        args = [f(x) for x in arguments['<args>']]

        x = w3.eth.contract(address=kista.load_contractAddress(name),
                            abi=kista.load_abi(name))
        x = kista.WrapContract(x)
    
        if func not in x.was:
            print("func not found")
            raise exit(2)

        result = x.getattr(func)(*args)

        print(result)

    else:
        print("dunno what to do", arguments)
        pass




"""
xNaval Fate.

Usage:
  kista.py deploy   <contract_name>            [<args>...]
  kista.py call     <contract_name> <function> [<args>...]
  kista.py transact <contract_name> <function> [<args>...]
  kista.py -h | --help
  kista.py --version

Options:
  -h --help     Show this screen.
  --version     Show version.
"""
from main import hello
hello()
exit()

import kista, docopt

def f(x):
    try:    return int(x)
    except: pass
    try:    return float(x)
    except: pass
    return x

arguments = docopt.docopt(__doc__, version=kista.version)

w3 = kista.w3_connect(0)

if not w3.isConnected():
    print("no connection")
    raise exit(1)

if arguments['deploy']:

    name = arguments['<contract_name>']
    args = [f(x) for x in arguments['<args>']]

    x = kista.deploy_contractAddress(name, *args)
    print(x)
    
elif arguments['call']:

    name = arguments['<contract_name>']
    func = arguments['<function>']
    args = [f(x) for x in arguments['<args>']]

    x = w3.eth.contract(address=kista.load_contractAddress(name),
                        abi=kista.load_abi(name))
    x = kista.WrapContract(x)
    
    if func not in x.ras:
        print("func not found")
        raise exit(2)

    result = x.getattr(func)(*args)

    print(result)

elif arguments['transact']:

    name = arguments['<contract_name>']
    func = arguments['<function>']
    args = [f(x) for x in arguments['<args>']]

    x = w3.eth.contract(address=kista.load_contractAddress(name),
                        abi=kista.load_abi(name))
    x = kista.WrapContract(x)
    
    if func not in x.was:
        print("func not found")
        raise exit(2)

    result = x.getattr(func)(*args)

    print(result)

else:
    print("dunno what to do", arguments)
    pass



from pathlib import Path
from setuptools import setup
from kista import __name__, version
#requirements=[x.strip()for x in open('requirements.txt').readlines()if x!='\n']
#requirements=(Path(__file__).parent / "requirements.txt").read_text()
long_description=(Path(__file__).parent / "README.md").read_text()
entry_points=dict(console_scripts=[f'{__name__}={__name__}.main:hello'])
setup(name=__name__,
      version=version,
      description='miscellaneous stuff, old norse for bag',
      long_description=long_description,
      long_description_content_type='text/markdown',
      url='https://github.com/circleclick-labs/'+__name__,
      author='Joel Ward',
      author_email='jmward+python@gmail.com',
      license='MIT',
      packages=[__name__],
      entry_points=entry_points,
      install_requires=['web3', 'docopt'],
      classifiers=[
          "Programming Language :: Python :: 3",
          "License :: OSI Approved :: MIT License",
          "Operating System :: OS Independent",
      ],
      zip_safe=True)
